package cn.estsh.i3plus.ext.mes.apiservice.serviceimpl.base;

import cn.estsh.i3plus.ext.mes.api.base.IMesPackingRuleDetailService;
import cn.estsh.i3plus.ext.mes.pojo.util.MesExtConstWords;
import cn.estsh.i3plus.platform.common.exception.ImppExceptionEnum;
import cn.estsh.i3plus.pojo.base.bean.DdlPackBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.tool.DdlPreparedPack;
import cn.estsh.i3plus.pojo.mes.bean.MesPackingRuleDetail;
import cn.estsh.i3plus.pojo.mes.util.MesExtEnumUtil;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
@Slf4j
public class MesPackingRuleDetailService extends BaseMesService<MesPackingRuleDetail> implements IMesPackingRuleDetailService {

    @Override
    protected void setPackQueryBean(MesPackingRuleDetail bean, DdlPackBean packBean) {
        DdlPreparedPack.getStringLikerPack(bean.getPackageCode(), MesExtConstWords.PACKAGE_CODE, packBean);
        DdlPreparedPack.getStringLikerPack(bean.getPartNo(), MesExtConstWords.PART_NO, packBean);
        DdlPreparedPack.getStringEqualPack(bean.getPartType(), MesExtConstWords.PART_TYPE, packBean);
    }

    @Override
    protected void onInsertBean(MesPackingRuleDetail item) {
        ValidatorBean.checkNotNull(item.getPackageCode(), "包装代码不能为空");
        ValidatorBean.checkNotNull(item.getPartNo(), "物料号不能为空");
        ValidatorBean.checkNotNull(item.getPartType(), "零件类型不能为空");

        DdlPackBean packBean = DdlPackBean.getDdlPackBean(item.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(item.getPackageCode(), MesExtConstWords.PACKAGE_CODE, packBean);
        DdlPreparedPack.getStringEqualPack(item.getPartType(), MesExtConstWords.PART_TYPE, packBean);
        Boolean flg = baseRDao.isExitByHql(packBean);
        if (flg) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("包装代码[%s]已经存在[%s]明细信息，请检查数据", item.getPackageCode(), MesExtEnumUtil.PACKING_RULE_DETAIL_PART_TYPE.valueOfDescription(item.getPartType()))
                    .build();
        }
    }

    @Override
    protected void onUpdateBean(MesPackingRuleDetail item) {
        ValidatorBean.checkNotNull(item.getId(), "包装代码不能为空");
        ValidatorBean.checkNotNull(item.getPackageCode(), "包装代码不能为空");
        ValidatorBean.checkNotNull(item.getPartNo(), "物料号不能为空");
        ValidatorBean.checkNotNull(item.getPartType(), "零件类型不能为空");

        DdlPackBean packBean = DdlPackBean.getDdlPackBean(item.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(item.getPackageCode(), MesExtConstWords.PACKAGE_CODE, packBean);
        DdlPreparedPack.getStringEqualPack(item.getPartType(), MesExtConstWords.PART_TYPE, packBean);
        DdlPreparedPack.getNumNOEqualPack(item.getId(), MesExtConstWords.ID, packBean);
        Boolean flg = baseRDao.isExitByHql(packBean);
        if (flg) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("包装代码[%s]已经存在[%s]明细信息，请检查数据", item.getPackageCode(), MesExtEnumUtil.PACKING_RULE_DETAIL_PART_TYPE.valueOfDescription(item.getPartType()))
                    .build();
        }
    }

    @Override
    public List<MesPackingRuleDetail> validateReturnImport(List<MesPackingRuleDetail> beanList) {
        for (MesPackingRuleDetail item : beanList) {
            onInsertBean(item);
        }
        return  beanList;
    }

}
