package cn.estsh.i3plus.ext.mes.apiservice.serviceimpl.base;

import cn.estsh.i3plus.ext.mes.api.base.IMesPackingRuleService;
import cn.estsh.i3plus.ext.mes.pojo.util.MesExtConstWords;
import cn.estsh.i3plus.platform.common.exception.ImppExceptionEnum;
import cn.estsh.i3plus.pojo.base.bean.DdlPackBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.tool.DdlPreparedPack;
import cn.estsh.i3plus.pojo.mes.bean.MesPackingRule;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.util.List;

@Service
@Slf4j
public class MesPackingRuleService extends BaseMesService<MesPackingRule> implements IMesPackingRuleService {

    @Override
    protected void setPackQueryBean(MesPackingRule bean, DdlPackBean packBean) {
        DdlPreparedPack.getStringLikerPack(bean.getPackageCode(), MesExtConstWords.PACKAGE_CODE, packBean);
        DdlPreparedPack.getNumEqualPack(bean.getDefaultFlag(), MesExtConstWords.DEFAULT_FLAG, packBean);
        DdlPreparedPack.getNumEqualPack(bean.getGenerateType(), MesExtConstWords.GENERATE_TYPE, packBean);
        DdlPreparedPack.getStringLikerPack(bean.getPackCode(), MesExtConstWords.PACK_CODE, packBean);
        DdlPreparedPack.getStringLikerPack(bean.getPackageBarcodeRule(), MesExtConstWords.PACKAGE_BARCODE_RULE, packBean);
        DdlPreparedPack.getStringLikerPack(bean.getPackageTemplate(), MesExtConstWords.PACKAGE_TEMPLATE, packBean);
        DdlPreparedPack.getStringLikerPack(bean.getPrinter(), MesExtConstWords.PRINTER, packBean);
    }

    @Override
    protected void onInsertBean(MesPackingRule item) {
        ValidatorBean.checkNotNull(item.getPackageCode(), "包装代码不能为空");
        ValidatorBean.checkNotNull(item.getGenerateType(), "统计方式不能为空");

        DdlPackBean packBean = DdlPackBean.getDdlPackBean(item.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(item.getPackageCode(), MesExtConstWords.PACKAGE_CODE, packBean);
        Boolean flg = baseRDao.isExitByHql(packBean);
        if (flg) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("包装代码[%s]信息已经存在，请检查数据", item.getPackageCode())
                    .build();
        }
        if (StringUtils.isEmpty(item.getDefaultFlag()) || item.getDefaultFlag().compareTo(CommonEnumUtil.TRUE_OR_FALSE.TRUE.getValue()) != 0) item.setDefaultFlag(CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue());
    }

    @Override
    protected void onUpdateBean(MesPackingRule item) {
        ValidatorBean.checkNotNull(item.getId(), "包装代码不能为空");
        ValidatorBean.checkNotNull(item.getPackageCode(), "包装代码不能为空");
        ValidatorBean.checkNotNull(item.getGenerateType(), "统计方式不能为空");

        DdlPackBean packBean = DdlPackBean.getDdlPackBean(item.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(item.getPackageCode(), MesExtConstWords.PACKAGE_CODE, packBean);
        DdlPreparedPack.getNumNOEqualPack(item.getId(), MesExtConstWords.ID, packBean);
        Boolean flg = baseRDao.isExitByHql(packBean);
        if (flg) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("包装代码[%s]信息已经存在，请检查数据", item.getPackageCode())
                    .build();
        }
        if (StringUtils.isEmpty(item.getDefaultFlag()) || item.getDefaultFlag().compareTo(CommonEnumUtil.TRUE_OR_FALSE.TRUE.getValue()) != 0) item.setDefaultFlag(CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue());
    }

    @Override
    public List<MesPackingRule> validateReturnImport(List<MesPackingRule> beanList) {
        for (MesPackingRule item : beanList) {
            onInsertBean(item);
        }
        return  beanList;
    }

}
